@@ -1,11 +1,11 @@
-use crate::Query;
+use crate::Command;
 use ql2::term::TermType;
 use std::ops::Not;
 
-impl Not for Query {
+impl Not for Command {
     type Output = Self;
 
     fn not(self) -> Self {
-        Query::new(TermType::Not).with_arg(self)
+        Self::new(TermType::Not).with_arg(self)
     }
 }
